@@ -15,50 +15,51 @@
 #' 
 #' @details The following plots are available for \code{spwb_day} and \code{pwb_day}:
 #' \itemize{
-#'   \item{\code{"LeafPsi"}:}{Leaf water potential (for shade and sunlit leaves).}
-#'   \item{\code{"LeafPsiAverage"}:}{Average leaf water potential.}
-#'   \item{\code{"RootPsi"}:}{Root crown water potential.}
-#'   \item{\code{"StemPsi"}:}{(Upper) stem water potential.}
-#'   \item{\code{"StemPLC"}:}{(Average) percentage of loss conductance in the stem conduits.}
-#'   \item{\code{"StemRWC"}:}{(Average) relative water content in the stem.}
-#'   \item{\code{"LeafRWC"}:}{Relative water content in the leaf.}
-#'   \item{\code{"StemSympRWC"}:}{(Average) relative water content in the stem symplasm.}
-#'   \item{\code{"LeafSympRWC"}:}{Relative water content in the leaf symplasm.}
-#'   \item{\code{"SoilPlantConductance"}:}{Overall soil plant conductance (calculated as the derivative of the supply function).}
-#'   \item{\code{"PlantExtraction"}:}{ Water extracted from each soil layer.}
-#'   \item{\code{"PlantTranspiration"}:}{ Plant cohort transpiration per ground area.}
-#'   \item{\code{"TranspirationPerLeaf"}:}{ Plant cohort transpiration per leaf area.}
-#'   \item{\code{"PlantGrossPhotosynthesis"}:}{ Plant cohort gross photosynthesis per ground area.}
-#'   \item{\code{"GrossPhotosynthesisPerLeaf"}:}{ Plant cohort gross photosynthesis per leaf area.}
-#'   \item{\code{"PlantNetPhotosynthesis"}:}{ Plant cohort net photosynthesis per ground area.}
-#'   \item{\code{"NetPhotosynthesisPerLeaf"}:}{ Plant cohort net photosynthesis per leaf area.}
-#'   \item{\code{"LeafTranspiration"}:}{ Instantaneous transpiration per leaf area (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafGrossPhotosynthesis"}:}{ Instantaneous gross photosynthesis per leaf area (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafNetPhotosynthesis"}:}{ Instantaneous net photosynthesis per leaf area (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafAbsorbedSWR"}:}{ Absorbed short wave radiation per leaf area (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafNetLWR"}:}{ Net long wave radiation per leaf area (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafCi"}:}{ Leaf intercellular CO2 concentration (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafIntrinsicWUE"}:}{ Leaf intrinsic water use efficiency, i.e. the ratio between instantaneous photosynthesis and stomatal conductance (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafVPD"}:}{ Leaf vapour pressure deficit (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafStomatalConductance"}:}{ Leaf stomatal conductance to water vapour (differentiates sunlit and shade leaves).}
-#'   \item{\code{"LeafTemperature"}:}{ Leaf temperature (differentiates sunlit and shade leaves).}
-#'   \item{\code{"Temperature"}:}{ Above-canopy, inside-canopy and soil temperature.}
-#'   \item{\code{"CanopyEnergyBalance"}:}{ Canopy energy balance components.}
-#'   \item{\code{"SoilEnergyBalance"}:}{ Soil energy balance components.}
-#'   \item{\code{"PlantWaterBalance"}:}{ Difference between water extraction from the soil and transpired water per ground area.}
-#'   \item{\code{"WaterBalancePerLeaf"}:}{ Difference between water extraction from the soil and transpired water per leaf area.}
+#'   \item{\code{"LeafPsi"}: Leaf water potential (for shade and sunlit leaves).}
+#'   \item{\code{"LeafPsiAverage"}: Average leaf water potential.}
+#'   \item{\code{"RootPsi"}: Root crown water potential.}
+#'   \item{\code{"StemPsi"}: Stem water potential.}
+#'   \item{\code{"StemPLC"}: (Average) percentage of loss conductance in the stem conduits.}
+#'   \item{\code{"StemRWC"}: (Average) relative water content in the stem.}
+#'   \item{\code{"LeafRWC"}: Relative water content in the leaf.}
+#'   \item{\code{"StemSympRWC"}: (Average) relative water content in the stem symplasm.}
+#'   \item{\code{"LeafSympRWC"}: Relative water content in the leaf symplasm.}
+#'   \item{\code{"SoilPlantConductance"}: Overall soil plant conductance (calculated as the derivative of the supply function).}
+#'   \item{\code{"PlantExtraction"}:  Water extracted from each soil layer.}
+#'   \item{\code{"PlantTranspiration"}: Plant cohort transpiration per ground area.}
+#'   \item{\code{"TranspirationPerLeaf"}: Plant cohort transpiration per leaf area.}
+#'   \item{\code{"PlantGrossPhotosynthesis"}: Plant cohort gross photosynthesis per ground area.}
+#'   \item{\code{"GrossPhotosynthesisPerLeaf"}: Plant cohort gross photosynthesis per leaf area.}
+#'   \item{\code{"PlantNetPhotosynthesis"}: Plant cohort net photosynthesis per ground area.}
+#'   \item{\code{"NetPhotosynthesisPerLeaf"}: Plant cohort net photosynthesis per leaf area.}
+#'   \item{\code{"LeafTranspiration"}: Instantaneous transpiration per leaf area (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafGrossPhotosynthesis"}: Instantaneous gross photosynthesis per leaf area (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafNetPhotosynthesis"}: Instantaneous net photosynthesis per leaf area (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafAbsorbedSWR"}: Absorbed short wave radiation per leaf area (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafAbsorbedPAR"}: Absorbed photosynthetically-active radiation per leaf area (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafNetLWR"}: Net long wave radiation per leaf area (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafCi"}: Leaf intercellular CO2 concentration (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafIntrinsicWUE"}: Leaf intrinsic water use efficiency, i.e. the ratio between instantaneous photosynthesis and stomatal conductance (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafVPD"}: Leaf vapour pressure deficit (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafStomatalConductance"}: Leaf stomatal conductance to water vapour (differentiates sunlit and shade leaves).}
+#'   \item{\code{"LeafTemperature"}: Leaf temperature (differentiates sunlit and shade leaves).}
+#'   \item{\code{"Temperature"}: Above-canopy, inside-canopy and soil temperature.}
+#'   \item{\code{"CanopyEnergyBalance"}: Canopy energy balance components.}
+#'   \item{\code{"SoilEnergyBalance"}: Soil energy balance components.}
+#'   \item{\code{"PlantWaterBalance"}: Difference between water extraction from the soil and transpired water per ground area.}
+#'   \item{\code{"WaterBalancePerLeaf"}: Difference between water extraction from the soil and transpired water per leaf area.}
 #' }
 #' And the following plots are additionally available for \code{growth_day}:
 #'   \itemize{
-#'     \item{\code{"GrossPhotosynthesis"}:}{ Gross photosynthesis rate per dry weight.}
-#'     \item{\code{"MaintenanceRespiration"}:}{ Maintenance respiration cost per dry weight.}
-#'     \item{\code{"RootExudation"}:}{ Root exudation rate per dry weight.}
-#'     \item{\code{"LabileCarbonBalance"}:}{ Labile carbon balance per dry weight.}
-#'     \item{\code{"SugarLeaf"}:}{ Sugar concentration in leaves.}
-#'     \item{\code{"StarchLeaf"}:}{ Starch concentration in leaves.}
-#'     \item{\code{"SugarSapwood"}:}{ Sugar concentration in sapwood.}
-#'     \item{\code{"StarchSapwood"}:}{ Starch concentration in sapwood.}
-#'     \item{\code{"SugarTransport"}:}{ Phloem sugar transport rate.}
+#'     \item{\code{"GrossPhotosynthesis"}: Gross photosynthesis rate per dry weight.}
+#'     \item{\code{"MaintenanceRespiration"}: Maintenance respiration cost per dry weight.}
+#'     \item{\code{"RootExudation"}: Root exudation rate per dry weight.}
+#'     \item{\code{"LabileCarbonBalance"}: Labile carbon balance per dry weight.}
+#'     \item{\code{"SugarLeaf"}: Sugar concentration in leaves.}
+#'     \item{\code{"StarchLeaf"}: Starch concentration in leaves.}
+#'     \item{\code{"SugarSapwood"}: Sugar concentration in sapwood.}
+#'     \item{\code{"StarchSapwood"}: Starch concentration in sapwood.}
+#'     \item{\code{"SugarTransport"}: Phloem sugar transport rate.}
 #'   }
 #'   
 #' @note Only for soil plant water balance simulations using \code{transpirationMode = "Sperry"} or \code{transpirationMode = "Cochard"}. This function can be used to display subdaily dynamics of corresponding to single days on \code{\link{spwb}} runs, if control option \code{subdailyResults} is set to \code{TRUE}. See also option \code{subdaily} in \code{\link{plot.spwb}}.
@@ -399,6 +400,23 @@ plot.pwb_day<-function(x, type="PlantTranspiration", bySpecies = FALSE,
     if(is.null(ylab)) ylab=.getYLab(type)
     return(.multiple_subday_dynamics_sunlit_shade(t(OM_SL), t(OM_SH), ylab = ylab, ylim = ylim))
   }
+  else if(type=="LeafAbsorbedPAR") {
+    OM_SL = SunlitLeavesInst$Abs_PAR
+    OM_SH = ShadeLeavesInst$Abs_PAR
+    if(bySpecies) {
+      m1 = apply(OM_SL,2, tapply, x$cohorts$Name, sum, na.rm=T)
+      lai1 = apply(x$SunlitLeaves$LAI,2, tapply, x$cohorts$Name, sum, na.rm=T)
+      OM_SL = m1/lai1
+      m1 = apply(OM_SH,2, tapply, x$cohorts$Name, sum, na.rm=T)
+      lai1 = apply(x$ShadeLeaves$LAI,2, tapply, x$cohorts$Name, sum, na.rm=T)
+      OM_SH = m1/lai1
+    } else {
+      OM_SL = OM_SL/x$SunlitLeaves$LAI
+      OM_SH = OM_SH/x$ShadeLeaves$LAI
+    }
+    if(is.null(ylab)) ylab=.getYLab(type)
+    return(.multiple_subday_dynamics_sunlit_shade(t(OM_SL), t(OM_SH), ylab = ylab, ylim = ylim))
+  }
   else if(type=="LeafNetLWR") {
     OM_SL = SunlitLeavesInst$Net_LWR
     OM_SH = ShadeLeavesInst$Net_LWR
