@@ -78,6 +78,11 @@
   TYPES <-c(TYPES,
             "Plant stress" = "PlantStress",
             "Stem PLC" = "StemPLC")
+  
+  if(transpirationMode %in% c("Sperry","Cochard")) {
+    TYPES <-c(TYPES,
+              "Leaf PLC" = "LeafPLC")
+  }
   return(TYPES)
 }
 .getSunlitShadePlotTypes<-function(transpirationMode = "Granier"){
@@ -251,6 +256,7 @@
             "Leaf gross photosynthesis" = "LeafGrossPhotosynthesis", 
             "Leaf net photosynthesis" = "LeafNetPhotosynthesis",
             "Absorbed SWR per leaf area" = "LeafAbsorbedSWR",
+            "Absorbed PAR per leaf area" = "LeafAbsorbedPAR",
             "Net LWR per leaf area" = "LeafNetLWR",
             "Leaf internal CO2" = "LeafCi", 
             "Leaf intrinsic WUE" = "LeafIntrinsicWUE",
@@ -320,7 +326,9 @@
   else if(type=="PlantLAI") ylab = expression(paste("Leaf area index ",(m^{-2}%.%m^{-2})))
   else if(type=="PlantLAIlive") ylab = expression(paste("(Live) leaf area index ",(m^{-2}%.%m^{-2})))
   else if(type=="AbsorbedSWRPerLeaf") ylab = expression(paste("Absorbed SWR per leaf area ",(MJ%.%m^{-2}%.%d^{-1})))
+  else if(type=="AbsorbedPARPerLeaf") ylab = expression(paste("Absorbed PAR per leaf area ",(MJ%.%m^{-2}%.%d^{-1})))
   else if(type=="LeafAbsorbedSWR") ylab = expression(paste("Absorbed SWR per leaf area ",(W%.%m^{-2})))
+  else if(type=="LeafAbsorbedPAR") ylab = expression(paste("Absorbed PAR per leaf area ",(W%.%m^{-2})))
   else if(type=="NetLWRPerLeaf") ylab = expression(paste("Net LWR per leaf area ",(MJ%.%m^{-2}%.%d^{-1})))
   else if(type=="LeafNetLWR") ylab = expression(paste("Net LWR per leaf area ",(W%.%m^{-2})))
   else if(type=="GrossPhotosynthesis") ylab=expression(paste("Gross photosynthesis ", (gGluc%.%gdry^{-1}%.%d^{-1})))
@@ -357,6 +365,7 @@
   else if(type=="MortalityRate") ylab = expression(paste("Mortality rate ",(ind %.% d^{-1})))
   else if(type=="LeafPI0")  ylab = expression(paste("Leaf osmotic potential at full turgor  ",(MPa)))
   else if(type=="StemPI0")  ylab = expression(paste("Stem osmotic potential at full turgor  ",(MPa)))
+  else if(type=="LeafPLC") ylab = "Percent loss conductance in leaves [%]"
   else if(type=="StemPLC") ylab = "Percent loss conductance in stem [%]"
   else if(type=="StemRWC") ylab = "Relative water content in stem [%]"
   else if(type=="StemSympRWC") ylab = "Relative water content in stem symplasm [%]"
@@ -877,8 +886,14 @@
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics_subdaily(m,  xlab = xlab, ylab = ylab, ylim = ylim))
   } 
-  else if(type %in% c("StemPsi", "RootPsi", "LeafRWC", "StemRWC", "StemPLC",
-                      "LeafSympRWC", "StemSympRWC", "LeafSympPsi", "StemSympPsi")) {
+  else if(type %in% c("LeafRWC", "StemRWC", "StemPLC",
+                      "LeafSympRWC", "StemSympRWC")) {
+    m = extractSubdaily(x, type, dates)[,c("datetime", cohorts), drop=FALSE]
+    m[, -1] <- 100*m[, -1]
+    if(is.null(ylab)) ylab = .getYLab(type)
+    return(.multiple_dynamics_subdaily(m,  xlab = xlab, ylab = ylab, ylim = ylim))
+  } 
+  else if(type %in% c("StemPsi", "RootPsi", "LeafSympPsi", "StemSympPsi")) {
     m = extractSubdaily(x, type, dates)[,c("datetime", cohorts), drop=FALSE]
     if(is.null(ylab)) ylab = .getYLab(type)
     return(.multiple_dynamics_subdaily(m,  xlab = xlab, ylab = ylab, ylim = ylim))
@@ -947,6 +962,12 @@
     if(is.null(ylab)) ylab=.getYLab(type)
     return(.multiple_dynamics_subdaily_sunlit_shade(mSu, mSh, ylab = ylab, ylim = ylim))
   } 
+  else if(type=="LeafAbsorbedPAR") {
+    mSu = extractSubdaily(x, "SunlitLeaves$Abs_PAR", dates)
+    mSh = extractSubdaily(x, "ShadeLeaves$Abs_PAR", dates)
+    if(is.null(ylab)) ylab=.getYLab(type)
+    return(.multiple_dynamics_subdaily_sunlit_shade(mSu, mSh, ylab = ylab, ylim = ylim))
+  } 
   else if(type=="LeafNetLWR") {
     mSu = extractSubdaily(x, "SunlitLeaves$Net_LWR", dates)[,c("datetime", cohorts), drop=FALSE]
     mSh = extractSubdaily(x, "ShadeLeaves$Net_LWR", dates)[,c("datetime", cohorts), drop=FALSE]
