@@ -157,6 +157,7 @@ test_that("Can produce all advanced subdaily spwb plots",{
     expect_s3_class(plot(S2, "LeafGrossPhotosynthesis", subdaily = TRUE), "ggplot")
     expect_s3_class(plot(S2, "PlantNetPhotosynthesis", subdaily = TRUE), "ggplot")
     expect_s3_class(plot(S2, "LeafNetPhotosynthesis", subdaily = TRUE), "ggplot")
+    expect_s3_class(plot(S2, "LeafAbsorbedPAR", subdaily = TRUE), "ggplot")
     expect_s3_class(plot(S2, "LeafAbsorbedSWR", subdaily = TRUE), "ggplot")
     expect_s3_class(plot(S2, "LeafNetLWR", subdaily = TRUE), "ggplot")
     expect_s3_class(plot(S2, "LeafCi", subdaily = TRUE), "ggplot")
@@ -182,6 +183,7 @@ test_that("Can produce all advanced subdaily spwb plots",{
     expect_s3_class(extractSubdaily(S2, output="PWB"), "data.frame")
     expect_s3_class(extractSubdaily(S2, output="Temperature"), "data.frame")
     expect_s3_class(extractSubdaily(S2, output="ExtractionInst"), "data.frame")
+    expect_s3_class(extractSubdaily(S2, output="SunlitLeaves$Abs_PAR"), "data.frame")
     expect_s3_class(extractSubdaily(S2, output="SunlitLeaves$Abs_SWR"), "data.frame")
     expect_s3_class(extractSubdaily(S2, output="SunlitLeaves$Net_LWR"), "data.frame")
     expect_s3_class(extractSubdaily(S2, output="SunlitLeaves$E"), "data.frame")
@@ -229,6 +231,7 @@ test_that("Can produce all advanced spwb_day plots",{
     expect_s3_class(plot(sd2, "LeafGrossPhotosynthesis"), "ggplot")
     expect_s3_class(plot(sd2, "LeafNetPhotosynthesis"), "ggplot")
     expect_s3_class(plot(sd2, "LeafAbsorbedSWR"), "ggplot")
+    expect_s3_class(plot(sd2, "LeafAbsorbedPAR"), "ggplot")
     expect_s3_class(plot(sd2, "LeafNetLWR"), "ggplot")
     expect_s3_class(plot(sd2, "LeafCi"), "ggplot")
     expect_s3_class(plot(sd2, "LeafIntrinsicWUE"), "ggplot")
