@@ -38,6 +38,12 @@ test_that("spwb can be run in example and empty forests",{
                        latitude = 41.82592, elevation = 100), "spwb")
 })
 
+test_that("pwb can be run in example and empty forests",{
+  x1 <- forest2spwbInput(exampleforestMED, examplesoil, SpParamsMED, control_granier)
+  S1 <- spwb(x1, examplemeteo[1:10,], latitude = 41.82592, elevation = 100)
+  expect_s3_class(pwb(x1, examplemeteo[1:10,], W = as.matrix(S1$Soil[,1:4]), 
+                       latitude = 41.82592, elevation = 100), "pwb")
+})
 test_that("spwb can be run using dates as columns",{
   expect_s3_class(spwb(forest2spwbInput(exampleforestMED, examplesoil, SpParamsMED, control_granier), 
                        examplemeteo2[1:10,],
